@@ -2,17 +2,17 @@ is_naka_parameters <- function(shape, scale) {
   if (!is.numeric(shape) | !is.numeric(scale)) {
     return(FALSE)
   }
-  if (any(shape < 1 / 2)) {
+  if (any(shape <= 0)) {
     return(FALSE)
   }
-  if (any(scale < 0)) {
+  if (any(scale <= 0)) {
     return(FALSE)
   }
   TRUE
 }
 
 attr(is_naka_parameters, "fail") <- function(call, env) {
-  paste0("'shape and scale are not valid parameter vectors")
+  paste0("shape and scale are not valid parameter vectors")
 }
 
 is_positive_integer <- function(x) {
